@@ -166,7 +166,11 @@ class JsonSchemaParser(Parser):
 
     def get_data_type(self, obj: JsonSchemaObject) -> List[DataType]:
         if obj.type is None:
-            raise ValueError(f'invalid schema object {obj}')
+            return [
+                self.data_type(
+                    type='Any', version_compatible=True, imports_=[IMPORT_ANY]
+                )
+            ]
         if isinstance(obj.type, list):
             types: List[str] = [t for t in obj.type if t != 'null']
             format_ = 'default'
@@ -363,7 +367,8 @@ class JsonSchemaParser(Parser):
             fields.append(
                 self.data_model_field_type(
                     name=field_name,
-                    example=field.examples,
+                    example=field.example,
+                    examples=field.examples,
                     description=field.description,
                     default=field.default,
                     title=field.title,
@@ -460,7 +465,8 @@ class JsonSchemaParser(Parser):
 
         field = self.data_model_field_type(
             data_types=item_obj_data_types,
-            example=obj.examples,
+            example=obj.example,
+            examples=obj.examples,
             default=obj.default,
             description=obj.description,
             title=obj.title,
@@ -510,7 +516,8 @@ class JsonSchemaParser(Parser):
                 self.data_model_field_type(
                     data_types=types,
                     description=obj.description,
-                    example=obj.examples,
+                    example=obj.example,
+                    examples=obj.examples,
                     default=obj.default,
                     required=not obj.nullable,
                 )
