@@ -52,6 +52,7 @@ class Types(Enum):
     number = auto()
     float = auto()
     double = auto()
+    decimal = auto()
     time = auto()
     string = auto()
     byte = auto()
@@ -67,6 +68,7 @@ class Types(Enum):
     uuid4 = auto()
     uuid5 = auto()
     uri = auto()
+    hostname = auto()
     ipv4 = auto()
     ipv6 = auto()
     boolean = auto()
